@@ -15,7 +15,8 @@
 namespace f3d
 {
 // Declared here for simplicity
-using option_variant_t = std::variant<bool, int, double, std::string, std::vector<double>>;
+using option_variant_t =
+  std::variant<bool, int, double, std::string, std::vector<double>, std::vector<int>>;
 
 /**
  * @class   options
@@ -213,6 +214,7 @@ public:
     } matcap;
 
     struct material {
+      std::optional<double> base_ior;
       std::optional<double> metallic;
       std::optional<double> roughness;
       std::optional<std::filesystem::path> texture;
@@ -234,10 +236,12 @@ public:
       bool cells = false;
       f3d::colormap_t colormap = f3d::colormap_t{0.0, 0.0, 0.0, 0.0, 0.4, 0.9, 0.0, 0.0, 0.8, 0.9, 0.9, 0.0, 1.0, 1.0, 1.0, 1.0};
       int component = -1;
+      std::optional<int> discretization;
       bool enable = false;
       std::optional<std::vector<double>> range;
     } scivis;
 
+    std::optional<f3d::transform2d_t> textures_transform;
     struct volume {
       bool enable = false;
       bool inverse = false;
@@ -305,7 +309,8 @@ public:
   struct scene {
     struct animation {
       bool autoplay = false;
-      int index = 0;
+      [[deprecated("use scene.animation.indices instead")]] int index = 0;
+      std::vector<int> indices = {0};
       f3d::ratio_t speed_factor = f3d::ratio_t{1.0};
     } animation;
 
@@ -314,6 +319,7 @@ public:
       std::optional<bool> orthographic;
     } camera;
 
+    std::optional<std::string> force_reader;
     f3d::direction_t up_direction = f3d::direction_t{0,1,0};
   } scene;
 
@@ -330,6 +336,7 @@ public:
     bool fps = false;
     bool loader_progress = false;
     bool metadata = false;
+    bool minimal_console = false;
     bool scalar_bar = false;
     f3d::ratio_t scale = f3d::ratio_t{1.0};
   } ui;
@@ -357,4 +364,9 @@ inline std::ostream& operator<<(std::ostream& os, const f3d::colormap_t& cm)
   os << f3d::options::format(cm);
   return os;
 }
+inline std::ostream& operator<<(std::ostream& os, const f3d::transform2d_t& transform)
+{
+  os << f3d::options::format(transform);
+  return os;
+}
 #endif
